@@ -1,6 +1,6 @@
 import re
 from pathlib import Path
-from typing import Type, Dict, Any, Generator, Union
+from typing import Type, Dict, Any, Generator, Union, List
 
 import obonet
 from collections_extended import setlist
@@ -71,3 +71,7 @@ class OBOKnowledgeParser(KnowledgeParserBase):
     @classmethod
     def get_model(cls) -> Type[BaseModel]:
         return OBOOptionsModel
+
+    @classmethod
+    def get_extensions(cls) -> List[str]:
+        return ["obo", "zip"]
\ No newline at end of file
